*-------------------------------------------------------------------------------

/*
TITLE: Figures and Tables

DESCRIPTION: Generates figures 4, 5, 6, A.2, and A.3. Generates data for tables
2, 3, 4, 5, and A.V.



*-------------------------------------------------------------------------------

TITLE: Figure 4

DESCRIPTION: Generates figure 4 graphic: Sign-up Rates for Private versus Public 
Decisions, NonHonors versus Honors Classes
*/

clear
set more off 
*cd "directory where the dataset is" 
use "Main_Data.dta"
preserve 

/* Regresses yesno against variables listed below; uses robust SEs and suppresses 
constant term */
reg yesno private_reg public_reg private_hon public_hon, robust noc 

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
mat R=J(4,4,.) 
local row=1

foreach X in private_reg public_reg private_hon public_hon   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R 

la var R1 "Sign-up rate" 

la var R4 Group //Labels column four by group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision" //Defines names for groups 
label values R4 groups //Applies groups to R4

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) /// 
	   (rcap R3 R2 R4, lc(gs5)), ///Plots confidence intervals
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.36 1 "72%") text(0.36 2 "61%") text(0.36 3 "92%") text(0.36 4 "93%") ///
	   graphregion(color(white))    ytitle("Sign-up rate") ///
	   text(1.1 1.5 "Non-honors classes") text(1.1 3.5 "Honors classes")  ///
	   text(0.85 1.5 "p-value=.007") text(0.97 3.5 "p-value=.631")

	   
graph save "figure4.gph", replace
graph export "figure4.pdf", replace
*-------------------------------------------------------------------------------

/*
TITLE: Figure 5

DESCRIPTION: Generates figure 5 graphic: Sign-up Rates for Private versus Public Decisions: Importance of Being
Popular (NonHonors Classes)
*/


clear*
set more off

use "Main_Data.dta"

//Generates interactions variables
gen popXprivate=(important==1 & private==1) 
gen popXpublic=(important==1 & public==1)
gen notpopXprivate=(important==0 & private==1)
gen notpopXpublic=(important==0 & public==1)

/* Regresses yesno against variables listed below; uses robust SEs and suppresses 
constant term*/
reg yesno popXprivate popXpublic notpopXprivate notpopXpublic if honor==0, robust noc

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
local row=1
mat R=J(4,4,.)

foreach X in popXprivate popXpublic notpopXprivate notpopXpublic   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R1 "Sign-up rate"

la var R4 Group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision"
label values R4 groups

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///Plots confidence intervals
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.30 1 "77%") text(0.30 2 "57%") text(0.30 3 "66%") text(0.30 4 "62%") ///
	   graphregion(color(white))    ytitle("Sign-up rate") ///
	   text(1.1 1.5 "Important to be popular") text(1.1 3.5 "Not important")  ///
	   text(0.85 1.5 "p-value=.002") text(0.85 3.5 "p-value=.427") 
	   
graph save "figure5.gph", replace
graph export "figure5.pdf", replace

*-------------------------------------------------------------------------------

/*
TITLE: Figure 6

DESCRIPTION: Generates figure 6 graphic: Sign-up Rates for Private versus Public Decisions: Importance of Being
Popular (Honors Classes)
*/

clear*
set more off

use "Main_Data.dta"

//Generates interactions variables
gen popXprivate=(important==1 & private==1) 
gen popXpublic=(important==1 & public==1)
gen notpopXprivate=(important==0 & private==1)
gen notpopXpublic=(important==0 & public==1)

/* Regresses yesno against variables listed below; uses robust SEs and suppresses 
constant term*/
reg yesno popXprivate popXpublic notpopXprivate notpopXpublic if honor==1, robust noc

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
local row=1
mat R=J(4,4,.)

foreach X in popXprivate popXpublic notpopXprivate notpopXpublic   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R1 "Sign-up rate"

la var R4 Group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision"
label values R4 groups

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///Plots confidence intervals
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.30 1 "93%") text(0.30 2 "98%") text(0.30 3 "91%") text(0.30 4 "90%") ///
	   text(1.04 1.5 "p-value=.269") text(0.95 3.5 "p-value=.922") ///
	   graphregion(color(white))    ytitle("Sign-up rate") ///
	   text(1.1 1.5 "Important to be popular") text(1.01 3.5 "Not important") 
	   
graph save "figure6.gph", replace
graph export "figure6.pdf", replace
*-------------------------------------------------------------------------------

/*
TITLE: Figure A.2

DESCRIPTION: Generates figure A.2 graphic: Sign-up Rates for Private versus Public 
Decisions, NonHonors versus Honors Classes: Students Taking Two Honors Classes
*/

clear
set more off 

use "Main_Data.dta"
 
/* Regresses yesno against variables listed below; uses robust SEs and suppresses 
constant term */
reg yesno private_reg public_reg private_hon public_hon if honor_ap_tot==2, robust noc 

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
mat R=J(4,4,.) 
local row=1

foreach X in private_reg public_reg private_hon public_hon   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R 

la var R1 "Sign-up rate" 

la var R4 Group //Labels column four by group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision" //Defines names for groups 
label values R4 groups //Applies groups to R4

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) /// 
	   (rcap R3 R2 R4, lc(gs5)), ///Plots confidence intervals
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.3 1 "79%") text(0.3 2 "54%") text(0.3 3 "72%") text(0.3 4 "97%") ///
	   graphregion(color(white))    ytitle("Sign-up rate") ///
	   text(.85 1.5 "p-value=.058") text(1.01 3.5 "p-value=.018") ///
	   text(1.1 1.5 "Non-honors classes") text(1.1 3.5 "Honors classes")

graph save "figurea2.gph", replace
graph export "figurea2.pdf", replace

*-------------------------------------------------------------------------------

/*
TITLE: Figure A.3

DESCRIPTION: Generates figure A.3 graphic: Login Rates for Private 
versus Public Decisions, NonHonors versus Honors Classes (Full Sample and Two-
Honors Students)
*/

***PANEL A
clear*
set more off
use "Main_Data.dta"

gen usage=(1-no_usage)

/* Regresses usage against variables listed below; uses robust SEs and suppresses 
constant term */
reg usage private_reg public_reg private_hon public_hon, robust noc

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
mat R=J(4,4,.)
local row=1

foreach X in private_reg public_reg private_hon public_hon   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

svmat R

la var R1 "Login rate"

la var R4 Group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision"
label values R4 groups

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.36 1 "57%") text(0.36 2 "49%%") text(0.36 3 "77%") text(0.36 4 "78%") ///
	   graphregion(color(white))    ytitle("Login rate") ///
	   text(1.1 1.5 "Non-honors classes") text(1.1 3.5 "Honors classes") /// 
	   text(0.95 1.5 "p-value=.0511") text(0.95 3.5 "p-value=.8574")

graph save "figurea3a.gph", replace
graph export "figurea3a.pdf", replace
	   
***PANEL B

/* Regresses usage against variables listed below; uses robust SEs and suppresses 
constant term */
reg usage private_reg public_reg private_hon public_hon if honor_ap_tot==2, robust noc

/* Creates a matrix with four rows, each representing one of the variables below.
The columns are: coefficient, lower bound of 95% conf int, upper bound of 95%
conf int, name of variable */
mat R=J(4,4,.)
local row=1

foreach X in private_reg public_reg private_hon public_hon   {

mat R[`row',1]=_b[`X']
mat R[`row',2]=_b[`X']-1.96*_se[`X']
mat R[`row',3]=_b[`X']+1.96*_se[`X']
mat R[`row',4]=`row'

local ++row
}

clear
svmat R

la var R1 "Login rate"

la var R4 Group
label define groups 1 "Private decision" 2 "Public decision" 3 "Private decision" 4 "Public decision"
label values R4 groups

set scheme s2mono
twoway (bar R1 R4, barw(0.6) fi(inten30) lc(black) lw(medium) ) ///
	   (rcap R3 R2 R4, lc(gs5)), ///
	   legend(off) xlabel(1/4, valuelabel) ///
	   ylabel(0(0.1)1) yscale(range(1.1))  ///
	   xline(2.5, lpattern(-) lcolor(black)) ///
	   text(0.2 1 "66%") text(0.2 2 "46%%") text(0.2 3 "60%") text(0.2 4 "83%") ///
	   graphregion(color(white))    ytitle("Login rate") ///
	   text(1.1 1.5 "Non-honors classes") text(1.1 3.5 "Honors classes") /// 
	   text(0.95 1.5 "p-value=.1583") text(0.95 3.5 "p-value=.0706")

graph save "figurea3b.gph", replace
graph export "figurea3b.pdf", replace

*-------------------------------------------------------------------------------

/*
TITLE: Tables 2-5

DESCRIPTION: Generates data for tables 2-5.

Table 2: Balance of covariates
Table 3: Effect of public treatment on sign-up decision
Table 4: Effect of public treatment on sign-up decision for students taking one to three honors classes
Table 5: Effect of public treatment on sign-up decision: by importance of popularity
*/

clear*
use "Main_Data.dta"
set more off

***** TABLE 2 - Balance of covariates

foreach x of varlist male age  hispanic honor_ap_tot gpa  {
sum `x'
ttest `x', by(public)  unequal
}

***** TABLE 3 - Main
xi: reg yesno public if honor==0, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket replace

xi: reg yesno public  male age hispanic if honor==0, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno public male age hispanic i.classroom i.surv if honor==0, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno public if honor==1, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno public  male age hispanic if honor==1, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno public male age hispanic i.classroom i.surv if honor==1, r
outreg2 using table3.xls, bdec(4) sdec(3) se  bracket append

**** TABLE 4 - Restricted Sample

gen one_hon=honor_ap_tot==1
gen two_hon=honor_ap_tot==2
gen three_hon=honor_ap_tot==3
gen four_hon=honor_ap_tot==4

replace one_hon=. if honor_ap_to==.
replace two_hon=. if honor_ap_to==.
replace three_hon=. if honor_ap_to==.
replace four_hon=. if honor_ap_to==.

gen one_honXhon = one_hon*honor
gen two_honXhon = two_hon*honor
gen three_honXhon = three_hon*honor

reg yesno public one_hon two_hon three_hon if honor_ap_to>0 & honor_ap_to<4 & honor==0, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket replace

reg yesno public one_hon two_hon three_hon male age hispanic if honor_ap_to>0 & honor_ap_to<4 & honor==0, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon male age hispanic  i.classroom i.surv if honor_ap_to>0 & honor_ap_to<4 & honor==0, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon male age hispanic total_honor_ms  total_honor_sosci i.classroom i.surv if honor_ap_to>0 & honor_ap_to<4 & honor==0, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon  if honor_ap_to>0 & honor_ap_to<4 & honor==1, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon male age hispanic if honor_ap_to>0 & honor_ap_to<4 & honor==1, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon male age hispanic  i.classroom i.surv if honor_ap_to>0 & honor_ap_to<4 & honor==1, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

reg yesno public one_hon two_hon three_hon male age hispanic total_honor_ms  total_honor_sosci i.classroom i.surv if honor_ap_to>0 & honor_ap_to<4 & honor==1, r
outreg2 using table4.xls, bdec(4) sdec(3) se  bracket append

***** TABLE 5 - Popularity:

gen publicXimportant=public*important
gen publicXnot=public*(1-important)

//regular
xi: reg yesno important publicXnot publicXimportant if honor==0, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket replace

xi: reg yesno important publicXnot publicXimportant male age hispanic if honor==0, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno important publicXnot publicXimportant male age hispanic i.classroom i.surv if honor==0, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket append

//honor
xi: reg yesno important publicXnot publicXimportant if honor==1, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno important publicXnot publicXimportant  male age hispanic if honor==1, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket append

xi: reg yesno important publicXnot publicXimportant male age hispanic i.classroom i.surv if honor==1, r
outreg2 using table5.xls, bdec(4) sdec(3) se  bracket append

*-------------------------------------------------------------------------------

/*
TITLE: Table A.V Balance of covariates - restricted sample

DESCRIPTION: Generates table A.V: balance of covariates for some-honors students
*/

**Panel A:

foreach x of varlist male age  hispanic  gpa total_honor_ms  total_honor_sosci honor_lang_art {
sum `x'
ttest `x' if honor_ap_t>=1 & honor_ap_to<=3 , by(public)  unequal
}

foreach x of varlist male age  hispanic  gpa total_honor_ms  total_honor_sosci honor_lang_art {
sum `x'
ttest `x' if honor_ap_t>=1 & honor_ap_to<=3 , by(honor)  unequal
}

**Panel B:
foreach x of varlist male age  hispanic  gpa total_honor_ms  total_honor_sosci honor_lang_art {
sum `x'
ttest `x' if honor_ap_t==2 , by(public)  unequal
}


foreach x of varlist male age  hispanic  gpa total_honor_ms  total_honor_sosci honor_lang_art {
sum `x'
ttest `x' if honor_ap_t==2 , by(honor)  unequal
}

